@@ -108,8 +108,7 @@ def GetHydrogenBondDistances(PDBDataFrame, ResidueStart, ResidueStop, Orientatio
                 HN = GetAtomPosition(PDBDataFrame, Segments[i+1],j+1,'HN')
                 CO = GetAtomPosition(PDBDataFrame, Segments[i],j,'O')
                 HBondDistances[i-1, int(numpy.where(ResiduesToCheck == j)[0])]=EuclideanDistance(HN, CO)
-                HBondDistances = pandas.DataFrame(HBondDistances)
-                HBondDistances.style.apply(lambda x: ["background: red" if v < 4 else "" for v in x], axis = 1)
+        HBondDistances = pandas.DataFrame(HBondDistances)
         return HBondDistances
     else:
         SegmentIDPairs = list(combinations(Segments, 2))
@@ -120,16 +119,23 @@ def GetHydrogenBondDistances(PDBDataFrame, ResidueStart, ResidueStop, Orientatio
             #HN of first segment to O of second segment
             HNArray = PDBDataFrame2[(PDBDataFrame2["atom_name"] == "HN") & (PDBDataFrame2["segment_id"] == SegmentPair[0])][["x_coord", "y_coord", "z_coord"]]
             COArray = PDBDataFrame2[(PDBDataFrame2["atom_name"] == "O") & (PDBDataFrame2["segment_id"] == SegmentPair[1])][["x_coord", "y_coord", "z_coord"]]
-            HBondDistances[SegmentPair[0]][SegmentPair[1]] = pandas.DataFrame(cdist(COArray, HNArray, metric = "euclidean"), index = range(ResidueStart, ResidueStop+1), columns =range(ResidueStart, ResidueStop+1))       
+            HBondDistances[SegmentPair[0]][SegmentPair[1]] = pandas.DataFrame(cdist(COArray, HNArray, metric = "euclidean"), index = range(ResidueStart, ResidueStop+1), columns =range(ResidueStart, ResidueStop+1))     
             #O  of first segment to HN of second segment
             HNArray2 = PDBDataFrame2[(PDBDataFrame2["atom_name"] == "HN") & (PDBDataFrame2["segment_id"] == SegmentPair[1])][["x_coord", "y_coord", "z_coord"]]
             COArray2 = PDBDataFrame2[(PDBDataFrame2["atom_name"] == "O") & (PDBDataFrame2["segment_id"] == SegmentPair[0])][["x_coord", "y_coord", "z_coord"]]
             HBondDistances[SegmentPair[1]][SegmentPair[0]] = pandas.DataFrame(cdist(COArray2, HNArray2, metric = "euclidean"), index = range(ResidueStart, ResidueStop+1), columns =range(ResidueStart, ResidueStop+1))    
-            HBondDistances.style.apply(lambda x: ["background: red" if v < 4 else "" for v in x], axis = 1)
-
             #Frames are displayed in order of residues, the horizontal represents the first segment, and the vertical represents the second segment 
+        
         return HBondDistances
-
+def StyleHydrogenBondDataFrame(DataFrame):
+    def ColorRed(val):
+        if val <= 2.0:
+            color = 'red'
+        else:
+            color = "none"   
+        return 'color: %s' % color
+    DataFrame = DataFrame.style.applymap(ColorRed)
+    return DataFrame
 
 def FindAngle(u,v):
     """
